@@ -2,6 +2,20 @@
 # Copyright 2002-2014 Luc Saffre
 # License: BSD (see file COPYING for details)
 
+""":mod:`lino_welfare` is the main module of Lino Welfare.
+
+.. autosummary::
+   :toctree:
+
+   modlib
+   migrate
+   projects
+   management.commands
+   models
+
+
+"""
+
 import os
 
 execfile(os.path.join(os.path.dirname(__file__), 'setup_info.py'))
