@@ -343,10 +343,10 @@ The total monthly amount available for debts distribution."""))
                 for m in household.member_set.all():
                     #~ if m.role and m.role.header:
                         #~ header = m.role.header
-                    if m.person.gender == mixins.Genders.male and not mr:
+                    if m.person.gender == dd.Genders.male and not mr:
                         header = unicode(_("Mr."))
                         mr = True
-                    elif m.person.gender == mixins.Genders.female and not mrs:
+                    elif m.person.gender == dd.Genders.female and not mrs:
                         header = unicode(_("Mrs."))
                         mrs = True
                     else:
